@@ -22,31 +22,31 @@ except Exception:
 
 
 import ramalama.chat as chat
-import ramalama.oci
 from ramalama import engine
 from ramalama.chat import default_prefix
 from ramalama.common import accel_image, get_accel, perror
 from ramalama.config import CONFIG, coerce_to_bool, load_file_config
+from ramalama.endian import EndianMismatchError
 from ramalama.logger import configure_logger, logger
-from ramalama.model import (
+from ramalama.model_inspect.error import ParseError
+from ramalama.model_store.global_store import GlobalModelStore
+from ramalama.rag import Rag, rag_image
+from ramalama.shortnames import Shortnames
+from ramalama.stack import Stack
+from ramalama.transports.base import (
     MODEL_TYPES,
     NoGGUFModelFileFound,
     NoRefFileFound,
     SafetensorModelNotSupported,
     trim_model_name,
 )
-from ramalama.model_factory import ModelFactory, New
-from ramalama.model_inspect.error import ParseError
-from ramalama.model_store.global_store import GlobalModelStore
-from ramalama.rag import rag_image
-from ramalama.shortnames import Shortnames
-from ramalama.stack import Stack
+from ramalama.transports.transport_factory import New, TransportFactory
 from ramalama.version import print_version, version
 
 shortnames = Shortnames()
 
 
-GENERATE_OPTIONS = ["quadlet", "kube", "quadlet/kube"]
+GENERATE_OPTIONS = ["quadlet", "kube", "quadlet/kube", "compose"]
 
 
 class ParsedGenerateInput:
@@ -626,6 +626,12 @@ def pull_parser(subparsers):
         default=True,
         help="require HTTPS and verify certificates when contacting registries",
     )
+    parser.add_argument(
+        "--verify",
+        default=CONFIG.verify,
+        action=CoerceToBool,
+        help="verify the model after pull, disable to allow pulling of models with different endianness",
+    )
     parser.add_argument("MODEL", completer=suppressCompleter)  # positional argument
     parser.set_defaults(func=pull_cli)
 
@@ -689,7 +695,7 @@ def convert_cli(args):
     if not tgt:
         tgt = target
 
-    model = ModelFactory(tgt, args).create_oci()
+    model = TransportFactory(tgt, args).create_oci()
 
     source_model = _get_source_model(args)
     args.carimage = rag_image(accel_image(CONFIG))
@@ -759,7 +765,7 @@ def push_cli(args):
                 raise e
         try:
             # attempt to push as a container image
-            m = ModelFactory(target, args).create_oci()
+            m = TransportFactory(target, args).create_oci()
             m.push(source_model, args)
         except Exception as e1:
             logger.debug(e1)
@@ -989,6 +995,7 @@ def chat_run_options(parser):
     )
     parser.add_argument("--prefix", type=str, help="prefix for the user prompt", default=default_prefix())
     parser.add_argument("--rag", type=str, help="a file or directory to use as context for the chat")
+    parser.add_argument("--mcp", nargs="*", help="MCP servers to use for the chat")
 
 
 def chat_parser(subparsers):
@@ -1048,7 +1055,7 @@ def run_cli(args):
         logger.debug(e)
         try:
             args.quiet = True
-            oci_model = ModelFactory(args.MODEL, args, ignore_stderr=True).create_oci()
+            oci_model = TransportFactory(args.MODEL, args, ignore_stderr=True).create_oci()
             oci_model.ensure_model_exists(args)
 
             oci_model.serve(args, quiet=True) if args.rag else oci_model.run(args)
@@ -1093,7 +1100,7 @@ def serve_cli(args):
     except KeyError as e:
         try:
             args.quiet = True
-            model = ModelFactory(args.MODEL, args, ignore_stderr=True).create_oci()
+            model = TransportFactory(args.MODEL, args, ignore_stderr=True).create_oci()
             model.serve(args)
         except Exception:
             raise e
@@ -1299,7 +1306,7 @@ formatted files to be processed""",
 
 
 def rag_cli(args):
-    rag = ramalama.rag.Rag(args.DESTINATION)
+    rag = Rag(args.DESTINATION)
     rag.generate(args)
 
 
@@ -1327,7 +1334,7 @@ def _rm_model(models, args):
                         raise e
             try:
                 # attempt to remove as a container image
-                m = ModelFactory(model, args, ignore_stderr=True).create_oci()
+                m = TransportFactory(model, args, ignore_stderr=True).create_oci()
                 m.remove(args)
                 return
             except Exception:
@@ -1427,6 +1434,8 @@ def main():
         eprint(e, errno.ENOSYS)
     except subprocess.CalledProcessError as e:
         eprint(e, e.returncode)
+    except EndianMismatchError:
+        sys.exit(1)
     except KeyboardInterrupt:
         sys.exit(0)
     except IOError as e:
